pub trait DialectConfig:
Default
+ Clone
+ Debug {
// Provided method
fn from_value(value: &Value) -> Self { ... }
}Expand description
Trait for dialect-specific configuration. Each dialect implements this to parse and validate its configuration from raw config values.
Provided Methods
Sourcefn from_value(value: &Value) -> Self
fn from_value(value: &Value) -> Self
Parse configuration from a Value (typically a Map from the config file’s dialect section). Returns the default configuration if parsing fails or if the input is None.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.